@@ -17,7 +17,7 @@ class DeleteQA:
     def run(self):
         branch_name = self._git.current_branch_name()
 
-        logger.info("Spengo il qa se esite...")
+        logger.info("Shutting down QA if it exists...")
         qainit_shutdown(branch_name, self._config)
 
         sys.exit()
