@@ -71,13 +71,7 @@ class MergePR:
             "Do you want to lock staging? (If you need to test on staging)",
             default=False,
         ):
-            if self._drone.prestart_success(drone_build_number):
-                self._captainhook.lock_project(self._project, "staging")
-            else:
-                logger.error(
-                    "There were problems with the drone build, can't lock staging"
-                )
-                sys.exit(-1)
+            self._captainhook.lock_project(self._project, "staging")
 
         if youtrack_id:
             logger.info("Updating card status on YouTrack...")
