@@ -53,6 +53,9 @@ class QA:
         table = Table()
         table.add_column("Name", style="purple")
         table.add_column("Hash", style="green")
+        table.add_column("Created by", style="white")
+        table.add_column("Updated by", style="white")
+        table.add_column("Deleted by", style="white")
         table.add_column("Status", style="white")
         console = Console()
 
@@ -63,6 +66,15 @@ class QA:
             table.add_row(
                 qa["name"],
                 qa["hash"],
+                qa.get("created", {}).get("github_username", "/")
+                if qa["created"] is not None
+                else "/",
+                qa.get("updated", {}).get("github_username", "/")
+                if qa["updated"] is not None
+                else "/",
+                qa.get("deleted", {}).get("github_username", "/")
+                if qa["deleted"] is not None
+                else "/",
                 qa["status"],
             )
         console.print(table)
@@ -71,6 +83,9 @@ class QA:
         table = Table()
         table.add_column("Name", style="purple")
         table.add_column("Hash", style="green")
+        table.add_column("Created by", style="white")
+        table.add_column("Updated by", style="white")
+        table.add_column("Deleted by", style="white")
         table.add_column("Status", style="white")
         console = Console()
         r = self._qainit.execute("GET", f"/api/v1/qa?user={user}")
@@ -80,6 +95,15 @@ class QA:
             table.add_row(
                 qa["name"],
                 qa["hash"],
+                qa.get("created", {}).get("github_username", "/")
+                if qa["created"] is not None
+                else "/",
+                qa.get("updated", {}).get("github_username", "/")
+                if qa["updated"] is not None
+                else "/",
+                qa.get("deleted", {}).get("github_username", "/")
+                if qa["deleted"] is not None
+                else "/",
                 qa["status"],
             )
         console.print(table)
