@@ -23,15 +23,19 @@ profiles_mapping = {
 
 
 class Secret:
-    def __init__(self, project, config, create_action, grant_action):
+    def __init__(self, project, config, create_action, grant_action, base_profile):
         self._project = project
         self._config = config
         self._path = os.path.join(config.user["projects_home"], project)
         self._vault = VaultHandler(project, config)
         self._create_action = create_action
         self._grant_action = grant_action
+        self._base_profile = base_profile
 
     def run(self):
+        if self._base_profile is not None:
+            self._config.vault["base_secret_profile"] = self._base_profile
+
         if self._create_action:
             self._create_new_secret()
             return
